# Chef_helper
Recipe - Food - Nutrition

1) Зробити логування в папку ДАТА +++++
2) Зробити ДокерФайл який запускає саме скрипт сервер.пай ++++++
3) загорнути та викласти на Пайпі де буде вхідний поінт який запускає клієнт.пай
195.201.150.230 Хост сервера
   (twine upload dist/* for pypi.org)